# Libchattedrooms
Official SDK for ChattedRooms, `libchattedrooms`.

Attempts to replicate some of the [PyCharacterAI](https://pypi.org/project/PyCharacterAI/) api.

MAY NOT WORK FULLY!

## Installation

```bash
pip install chattedrooms
```

## Requirements

- Python >= 3.8
- requests
- aiohttp
- websockets

## EXample

```python
import chattedrooms

# Example usage here
```

## Links

- [Homepage](https://github.com/RoominatorAI/sdk)
- [Issues](https://github.com/RoominatorAI/sdk/issues)

## License

MIT License